HypercuboidCheckerboard

Struct HypercuboidCheckerboard 

pub struct HypercuboidCheckerboard<const N: usize> { /* private fields */ }
2^N color checkerboard with axis-aligned hypercuboidal cells.

A HypercuboidCheckerboard is comprised of n x m x … axis aligned spaces. Each space has the same shape, but each axis might have a different edge length. Each axis may be periodic or not.

Along the non-periodic axes, the checkerboard overhangs the boundary so that the entire domain is always covered (for any origin shift up to 1 cell length). Along periodic axes, the checkerboard has exactly the same width as the domain. HypercuboidCheckerboard wraps points “outside” the checkerboard into the correct periodic space.

Obviously, HypercuboidCheckerboard is a suitable checkerboard for Hypercuboid boundary geometries. It can also be a good choice for other boundaries. For example: cylindrical boundaries (periodic in one direction) and closed boundaries of any shape. There may be many overhanging spaces (some completely outside the boundary) in these cases. However, the checkerboard is still valid and rayon’s dynamic load balancing scheme should be able to handle the empty cells efficiently.

Implementations

Source

impl<const N: usize> HypercuboidCheckerboard<N>

pub fn new<R: Rng + ?Sized>( rng: &mut R, interaction_range: PositiveReal, edge_lengths: [PositiveReal; N], periodic: [bool; N], ) -> Self

Construct a new HypercuboidCheckerboard.

Set interaction_range to the largest distance between any two interacting bodies. new will construct a checkerboard that covers the range [-edge_lengths[i]/2.0, edge_lengths[i]/2.0) (respecting periodic[i]) for each dimension i.

pub fn update<R: Rng + ?Sized>( &mut self, rng: &mut R, interaction_range: PositiveReal, edge_lengths: [PositiveReal; N], periodic: [bool; N], )

Update an existing checkerboard.

update performs the same steps as new, but modifies self in place. Prefer update when possible, as it can reuse the space index partitioning when the shape doesn’t change.