ParallelSweep

Struct ParallelSweep 

pub struct ParallelSweep<L, K, B, S> { /* private fields */ }
In parallel, apply local trial moves to bodies in the microstate.

The generic type names are:

Example

use hoomd_mc::{HypercuboidCheckerboard, ParallelSweep, Translate};
use hoomd_microstate::property::Point;
use hoomd_vector::Cartesian;

let d = 0.1;
let translate =
    Translate::<Cartesian<2>>::with_maximum_distance(d.try_into()?);
let translate_sweep = ParallelSweep::<
    _,
    HypercuboidCheckerboard<2>,
    Point<Cartesian<2>>,
    Point<Cartesian<2>>,
>::new(1.0.try_into()?, translate);

Implementations

Source

impl<L, K, B, S> ParallelSweep<L, K, B, S>
where K: Default,

pub fn new(body_interaction_range: PositiveReal, local_trial: L) -> Self

Construct a new ParallelSweep.

To avoid applying conflicting moves at the same time, you need to provide the largest distance between any two interacting bodies: body_interaction_range (measured between the body positions). ParallelSweep cannot compute this value, nor can it validate whether the provided value is correct.

The local_trial arguments determines what trial moves ParallelSweep attempts.

Example
use hoomd_mc::{HypercuboidCheckerboard, ParallelSweep, Translate};
use hoomd_microstate::property::Point;
use hoomd_vector::Cartesian;

let d = 0.1;
let translate =
    Translate::<Cartesian<2>>::with_maximum_distance(d.try_into()?);
let translate_sweep = ParallelSweep::<
    _,
    HypercuboidCheckerboard<2>,
    Point<Cartesian<2>>,
    Point<Cartesian<2>>,
>::new(1.0.try_into()?, translate);
Source

impl<L, K, B, S> ParallelSweep<L, K, B, S>

pub fn body_interaction_range(&self) -> &PositiveReal

Get the body interaction range.

pub fn body_interaction_range_mut(&mut self) -> &mut PositiveReal

Get the body interaction range (mutable).

pub fn local_trial(&self) -> &L

Get the local trial.

pub fn local_trial_mut(&mut self) -> &mut L

Get the local trial (mutable).