Rotate

Struct Rotate 

pub struct Rotate<O> { /* private fields */ }
Change the orientation of a body by a small amount.

Rotate proposes local trial moves that rotate the orientation of a body by a small amount. The maximum_rotation parameter sets the largest possible rotation.

When proposing trial moves for Angle, maximum_rotation is measured in radians and the rotation is uniformly chosen between -maximum_rotation and maximum_rotation.

When proposing trial moves for Versor, maximum_rotation is measured in radians and the width of a Gaussian distribution centered on 0.

The generic type names are:

  • O: The type of the orientation to rotate.

Example

use hoomd_mc::Rotate;
use hoomd_vector::Angle;

let a = 0.1;
let rotate = Rotate::<Angle>::with_maximum_rotation(a.try_into()?);

Implementations

Source

impl<P> Rotate<P>

pub fn with_maximum_rotation(maximum_rotation: PositiveReal) -> Self

Construct a Rotate move with the given maximum rotation.

Example
use hoomd_mc::Rotate;
use hoomd_vector::Angle;

let a = 0.1;
let rotate = Rotate::<Angle>::with_maximum_rotation(a.try_into()?);
pub fn maximum_rotation(&self) -> &PositiveReal

Get the maximum rotation.

pub fn maximum_rotation_mut(&mut self) -> &mut PositiveReal

Get the maximum rotation.