pub struct Sweep<L>(pub L);Expand description
Apply a local trial move to bodies in the microstate.
The first field in the tuple struct determines what trial moves Sweep
attempts. Sweep::apply applies the trial move to each body in the
microstate once. Sweep::apply_with_filter applies the trial move
to select bodies.
Example
use hoomd_mc::{Sweep, Translate};
use hoomd_vector::Cartesian;
let d = 0.1;
let translate =
Translate::<Cartesian<2>>::with_maximum_distance(d.try_into()?);
let translate_sweep = Sweep(translate);Tuple Fields
0: LImplementations
Sourceimpl<L> Sweep<L>
impl<L> Sweep<L>
Sourcepub fn apply_with_filter<P, B, S, X, C, H, MA, F>(
&self,
microstate: &mut Microstate<B, S, X, C>,
hamiltonian: &H,
macrostate: &MA,
should_move_body: F,
) -> Countwhere
P: Copy,
B: Copy + Default + Transform<S> + Position<Position = P>,
S: Copy + Default + Position<Position = P>,
X: PointUpdate<P, SiteKey>,
L: LocalTrial<B>,
H: DeltaEnergyOne<B, S, X, C>,
C: Wrap<B> + Wrap<S> + GenerateGhosts<S>,
MA: Temperature,
F: Fn(&Tagged<Body<B, S>>) -> bool,
pub fn apply_with_filter<P, B, S, X, C, H, MA, F>(
&self,
microstate: &mut Microstate<B, S, X, C>,
hamiltonian: &H,
macrostate: &MA,
should_move_body: F,
) -> Countwhere
P: Copy,
B: Copy + Default + Transform<S> + Position<Position = P>,
S: Copy + Default + Position<Position = P>,
X: PointUpdate<P, SiteKey>,
L: LocalTrial<B>,
H: DeltaEnergyOne<B, S, X, C>,
C: Wrap<B> + Wrap<S> + GenerateGhosts<S>,
MA: Temperature,
F: Fn(&Tagged<Body<B, S>>) -> bool,
Apply a local trial move to select bodies in the microstate.
apply_with_filter applies trial moves to bodies where should_move_body
returns true.
Each trial move is accepted when:
r < \exp\left(\frac{-\Delta H}{kT}\right)where r is a random value uniformly distributed in [0,1), $\Delta H$ is
the change in energy computed by the given hamiltonian and $kT$ is the
temperature given in macrostate.
Example
use hoomd_interaction::Zero;
use hoomd_mc::{Sweep, Translate, Trial};
use hoomd_microstate::{Body, Microstate, property::Position};
use hoomd_simulation::macrostate::Isothermal;
use hoomd_vector::Cartesian;
let mut microstate = Microstate::new();
microstate.add_body(Body::point(Cartesian::from([0.0, 0.0])));
microstate.add_body(Body::point(Cartesian::from([1.0, 0.0])));
microstate.add_body(Body::point(Cartesian::from([0.0, 1.0])));
let d = 0.1;
let translate = Translate::with_maximum_distance(d.try_into()?);
let mut translate_sweep = Sweep(translate);
let hamiltonian = Zero;
let macrostate = Isothermal { temperature: 1.0 };
for _ in 0..1_000 {
translate_sweep.apply_with_filter(
&mut microstate,
&hamiltonian,
¯ostate,
|b| b.tag != 0,
);
microstate.increment_step();
}
assert_eq!(
microstate.bodies()[0].item.properties.position,
[0.0, 0.0].into()
);Sourcepub fn tune_with_options_and_filter<P, B, S, X, C, H, MA, F>(
&mut self,
microstate: &Microstate<B, S, X, C>,
hamiltonian: &H,
macrostate: &MA,
options: &TuneOptions,
should_move_body: F,
)where
P: Copy,
B: Copy + Default + Transform<S> + Position<Position = P>,
S: Copy + Default + Position<Position = P>,
X: PointUpdate<P, SiteKey>,
L: LocalTrial<B> + Adjust + Display,
H: DeltaEnergyOne<B, S, X, C>,
C: Wrap<B> + Wrap<S> + GenerateGhosts<S>,
MA: Temperature,
F: Fn(&Tagged<Body<B, S>>) -> bool,
pub fn tune_with_options_and_filter<P, B, S, X, C, H, MA, F>(
&mut self,
microstate: &Microstate<B, S, X, C>,
hamiltonian: &H,
macrostate: &MA,
options: &TuneOptions,
should_move_body: F,
)where
P: Copy,
B: Copy + Default + Transform<S> + Position<Position = P>,
S: Copy + Default + Position<Position = P>,
X: PointUpdate<P, SiteKey>,
L: LocalTrial<B> + Adjust + Display,
H: DeltaEnergyOne<B, S, X, C>,
C: Wrap<B> + Wrap<S> + GenerateGhosts<S>,
MA: Temperature,
F: Fn(&Tagged<Body<B, S>>) -> bool,
Tune the trial move maximum size to achieve a given acceptance ratio.
tune_with_options_and_filter applies trial moves to bodies where
should_move_body returns true.
Example
use hoomd_geometry::shape::Rectangle;
use hoomd_interaction::{
MaximumInteractionRange, PairwiseCutoff, pairwise::HardSphere,
};
use hoomd_mc::{Sweep, Translate, Trial, Tune, TuneOptions};
use hoomd_microstate::{
Body, Microstate, boundary::Periodic, property::Position,
};
use hoomd_simulation::macrostate::Isothermal;
use hoomd_vector::Cartesian;
let square = Rectangle::with_equal_edges(2.2.try_into()?);
let mut microstate = Microstate::builder()
.boundary(Periodic::new(1.0, square)?)
.try_build()?;
microstate.add_body(Body::point(Cartesian::from([-0.6, -0.6])))?;
microstate.add_body(Body::point(Cartesian::from([-0.6, 0.6])))?;
microstate.add_body(Body::point(Cartesian::from([0.6, -0.6])))?;
microstate.add_body(Body::point(Cartesian::from([0.6, 0.6])))?;
let d = 0.1;
let translate = Translate::with_maximum_distance(d.try_into()?);
let mut translate_sweep = Sweep(translate);
let hamiltonian = PairwiseCutoff(HardSphere { diameter: 1.0 });
let macrostate = Isothermal { temperature: 1.0 };
translate_sweep.tune_with_options_and_filter(
µstate,
&hamiltonian,
¯ostate,
&TuneOptions::default(),
|b| b.tag >= 2,
);