Translate

Struct Translate 

pub struct Translate<P> { /* private fields */ }
Move the position of a body by a small distance.

Translate proposes local trial moves that translate the position of a body in space by up to a maximum distance, given by a PositiveReal.

The generic type names are:

  • P: The type of the point to translate.

Example

use hoomd_mc::Translate;
use hoomd_vector::Cartesian;

let d = 0.1;
let translate =
    Translate::<Cartesian<2>>::with_maximum_distance(d.try_into()?);

Implementations

Source

impl<P> Translate<P>

pub fn with_maximum_distance(maximum_distance: PositiveReal) -> Self

Construct a Translate move with the given maximum distance.

Example
use hoomd_mc::Translate;
use hoomd_vector::Cartesian;

let d = 0.1;
let translate =
    Translate::<Cartesian<2>>::with_maximum_distance(d.try_into()?);
pub fn maximum_distance(&self) -> &PositiveReal

Get the maximum distance.

pub fn maximum_distance_mut(&mut self) -> &mut PositiveReal

Get the maximum distance.