Adjust

Trait Adjust 

pub trait Adjust {
    // Required method
    fn adjust(&mut self, factor: PositiveReal);
}
Change the maximum size of a local trial move.

Required Methods

fn adjust(&mut self, factor: PositiveReal)

Change the maximum trial move size by the given scale factor.

Implementors