pub fn tune_by_scaling<L>(
trial: &mut L,
target_acceptance: OpenUnitIntervalNumber,
count: &Count,
)where
L: Adjust,Expand description
Tune adjustable move sizes toward a target acceptance ratio.
Use Sweep::tune or ParallelSweep::tune when tuning local trial move
sizes. tune_by_scaling is an internal implementation detail that you can
use to tune custom trial moves.
Pass tune_by_scaling a target acceptance ratio and the move count
obtained during a sampling period with the current trial move size.
tune_by_scaling will scale the trial move size by the factor:
\frac{a + \gamma}{t + \gamma}where $a$ is the current acceptance (from count), $t$ is the target
and $\gamma = 1.5$.