pub struct Translate<P> { /* private fields */ }Expand description
Move the position of a body by a small distance.
Translate proposes local trial moves that translate the position of a body
in space by up to a maximum distance, given by a PositiveReal.
The generic type names are:
P: The type of the point to translate.
Example
use hoomd_mc::Translate;
use hoomd_vector::Cartesian;
let d = 0.1;
let translate =
Translate::<Cartesian<2>>::with_maximum_distance(d.try_into()?);Implementations
Sourceimpl<P> Translate<P>
impl<P> Translate<P>
Sourcepub fn with_maximum_distance(maximum_distance: PositiveReal) -> Self
pub fn with_maximum_distance(maximum_distance: PositiveReal) -> Self
Sourcepub fn maximum_distance(&self) -> &PositiveReal
pub fn maximum_distance(&self) -> &PositiveReal
Get the maximum distance.
Sourcepub fn maximum_distance_mut(&mut self) -> &mut PositiveReal
pub fn maximum_distance_mut(&mut self) -> &mut PositiveReal
Get the maximum distance.