pub struct UniformIn<S, C> {
pub boundary: C,
pub template_sites: Vec<S>,
}Expand description
Generate bodies uniformly in the given boundary condition.
Give UniformIn a template vector of sites and it will randomly generate
bodies uniformly distributed in the given boundary. Each generated body will
have the same sites (cloned from template_sites) and random body properties
sampled in the given boundary.
Example
Place points at random locations in the boundary:
use hoomd_geometry::{IsPointInside, shape::Rectangle};
use hoomd_mc::{BodyDistribution, UniformIn};
use hoomd_microstate::{Body, boundary::Closed, property::Point};
use hoomd_vector::Cartesian;
use rand::{SeedableRng, distr::Distribution, rngs::StdRng};
let rectangle = Closed(Rectangle::with_equal_edges(5.0.try_into()?));
let mut rng = StdRng::seed_from_u64(1);
let uniform_in = UniformIn {
boundary: rectangle,
template_sites: vec![Point::new(Cartesian::from([0.0, 0.0]))],
};
let body: Body<Point<Cartesian<2>>, Point<Cartesian<2>>> =
uniform_in.sample(0, &mut rng);
assert!(
uniform_in
.boundary
.0
.is_point_inside(&body.properties.position)
);Place oriented bodies at random locations in the boundary and give them random orientations:
use rand::{SeedableRng, rngs::StdRng};
use std::f64::consts::PI;
use hoomd_geometry::{IsPointInside, shape::Rectangle};
use hoomd_mc::{BodyDistribution, UniformIn};
use hoomd_microstate::{
Body,
boundary::Closed,
property::{OrientedPoint, Point},
};
use hoomd_vector::{Angle, Cartesian};
let rectangle = Closed(Rectangle::with_equal_edges(5.0.try_into()?));
let mut rng = StdRng::seed_from_u64(1);
let uniform_in = UniformIn {
boundary: rectangle,
template_sites: vec![
Point::new(Cartesian::from([-1.0, 0.0])),
Point::new(Cartesian::from([1.0, 0.0])),
],
};
let body: Body<OrientedPoint<Cartesian<2>, Angle>, Point<Cartesian<2>>> =
uniform_in.sample(0, &mut rng);
assert!(
uniform_in
.boundary
.0
.is_point_inside(&body.properties.position)
);
assert!(body.properties.orientation.theta < 2.0 * PI);Fields
boundary: CGenerate bodies inside this boundary.
template_sites: Vec<S>Give each generated body these sites.