pub trait Adjust {
// Required method
fn adjust(&mut self, factor: PositiveReal);
}Expand description
Change the maximum size of a local trial move.
Required Methods
Sourcefn adjust(&mut self, factor: PositiveReal)
fn adjust(&mut self, factor: PositiveReal)
Change the maximum trial move size by the given scale factor.